@@ -159,11 +159,6 @@ bool kcm_cc_access(struct kcm_ccache *cc,
         return false;
     }
 
-    if (uid == 0 && gid == 0) {
-        /* root can access any ccache */
-        return true;
-    }
-
     ok = ((cc->owner.uid == uid) && (cc->owner.gid == gid));
     if (!ok) {
         DEBUG(SSSDBG_MINOR_FAILURE,
@@ -1164,9 +1159,6 @@ static void kcm_ccdb_name_by_uuid_done(struct tevent_req *subreq)
     ret = state->db->ops->name_by_uuid_recv(subreq, state, &state->name);
     talloc_zfree(subreq);
     if (ret != EOK) {
-        DEBUG(SSSDBG_OP_FAILURE,
-              "Failed to resolve cache by UUID [%d]: %s\n",
-              ret, sss_strerror(ret));
         tevent_req_error(req, ret);
         return;
     }
@@ -1244,9 +1236,6 @@ static void kcm_ccdb_uuid_by_name_done(struct tevent_req *subreq)
     ret = state->db->ops->uuid_by_name_recv(subreq, state, state->uuid);
     talloc_zfree(subreq);
     if (ret != EOK) {
-        DEBUG(SSSDBG_OP_FAILURE,
-              "Failed to resolve cache by UUID [%d]: %s\n",
-              ret, sss_strerror(ret));
         tevent_req_error(req, ret);
         return;
     }
